.\" **************************************************************************
.\" *                                  _   _ ____  _
.\" *  Project                     ___| | | |  _ \| |
.\" *                             / __| | | | |_) | |
.\" *                            | (__| |_| |  _ <| |___
.\" *                             \___|\___/|_| \_\_____|
.\" *
.\" * Copyright (C) 1998 - 2022, Daniel Stenberg, <daniel@haxx.se>, et al.
.\" *
.\" * This software is licensed as described in the file COPYING, which
.\" * you should have received as part of this distribution. The terms
.\" * are also available at https://curl.se/docs/copyright.html.
.\" *
.\" * You may opt to use, copy, modify, merge, publish, distribute and/or sell
.\" * copies of the Software, and permit persons to whom the Software is
.\" * furnished to do so, under the terms of the COPYING file.
.\" *
.\" * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
.\" * KIND, either express or implied.
.\" *
.\" * SPDX-License-Identifier: curl
.\" *
.\" **************************************************************************
.TH CURLSHOPT_UNSHARE 3 "8 Aug 2003" "libcurl 7.10.7" "libcurl Manual"
.SH NAME
CURLSHOPT_UNSHARE - remove data to share
.SH SYNOPSIS
.nf
#include <curl/curl.h>

CURLSHcode curl_share_setopt(CURLSH *share, CURLSHOPT_UNSHARE, long type);
.fi
.SH DESCRIPTION
The \fItype\fP parameter specifies what specific data that should no longer be
shared and kept in the share object that was created with
\fIcurl_share_init(3)\fP. In other words, stop sharing that data in this
shared object. The given \fItype\fP must be be one of the values described
below. You can set \fICURLSHOPT_UNSHARE(3)\fP multiple times with different
data arguments to remove multiple types from the shared object. Add data to
share again with \fICURLSHOPT_SHARE(3)\fP.
.IP CURL_LOCK_DATA_COOKIE
Cookie data will no longer be shared across the easy handles using this shared
object.
.IP CURL_LOCK_DATA_DNS
Cached DNS hosts will be no longer be shared across the easy handles using
this shared object.
.IP CURL_LOCK_DATA_SSL_SESSION
SSL session IDs will no longer be shared across the easy handles using this
shared object.
.IP CURL_LOCK_DATA_CONNECT
The connection cache is no longer shared.
.IP CURL_LOCK_DATA_PSL
The Public Suffix List is no longer shared.
.SH PROTOCOLS
All
.SH EXAMPLE
.nf
  CURLSHcode sh;
  share = curl_share_init();
  sh = curl_share_setopt(share, CURLSHOPT_UNSHARE, CURL_LOCK_DATA_COOKIE);
  if(sh)
    printf("Error: %s\\n", curl_share_strerror(sh));
.fi
.SH AVAILABILITY
Added in 7.10
.SH RETURN VALUE
CURLSHE_OK (zero) means that the option was set properly, non-zero means an
error occurred. See \fIlibcurl-errors(3)\fP for the full list with
descriptions.
.SH "SEE ALSO"
.BR CURLSHOPT_SHARE "(3), "
.BR curl_share_setopt "(3), " curl_share_cleanup "(3), " curl_share_init "(3)"
